@@ -4,20 +4,14 @@ ACT: The Atmospheric Community Toolkit
 
 """
 
-from . import io
-from . import plotting
-from . import corrections
-from . import utils
-from . import tests
-from . import discovery
-from . import retrievals
-from . import qc
-from ._version import get_versions
-
 # No more pandas warnings
 from pandas.plotting import register_matplotlib_converters
+
+from . import corrections, discovery, io, plotting, qc, retrievals, tests, utils
+from ._version import get_versions
+
 register_matplotlib_converters()
 
 # Version for source builds
 vdict = get_versions()
-__version__ = vdict["version"]
+__version__ = vdict['version']
