@@ -62,25 +62,30 @@ def read_psl_wind_profiler(filename, transpose=True):
         date_str = list(map(int, date_str))
         # Datetime not taking into account the utc offset yet
         time = dt.datetime(
-            2000 + date_str[0], date_str[1], date_str[2], date_str[3],
-            date_str[4], date_str[5])
+            2000 + date_str[0],
+            date_str[1],
+            date_str[2],
+            date_str[3],
+            date_str[4],
+            date_str[5],
+        )
 
         mode = df.iloc[idx[0][i] + 7][0]
         mode = int(mode.split(' ')[-1])
 
         df_array = np.array(
-            df.iloc[idx[0][i] + 10:idx[0][i + 1] - 1][0].str.split(
-                r'\s{2,}').tolist(), dtype='float')
+            df.iloc[idx[0][i] + 10 : idx[0][i + 1] - 1][0].str.split(r'\s{2,}').tolist(),
+            dtype='float',
+        )
         df_add = pd.DataFrame(df_array, columns=column_list)
         df_add = df_add.replace(999999.0, np.nan)
 
         xr_add = df_add.to_xarray()
         xr_add = xr_add.swap_dims({'index': 'height'})
         xr_add = xr_add.reset_coords('index')
-        xr_add = xr_add.assign_coords(
-            {'time': np.array(time), 'height': xr_add['HT'].values})
+        xr_add = xr_add.assign_coords({'time': np.array(time), 'height': xr_add['HT'].values})
 
-        if mode < 1000.:
+        if mode < 1000.0:
             low.append(xr_add)
         else:
             hi.append(xr_add)
