@@ -4,19 +4,21 @@ cf-compliance.
 
 """
 
-import xarray as xr
-import re
-import numpy as np
 import copy
+import re
+
+import numpy as np
+import xarray as xr
 
 from act.qc.qcfilter import parse_bit
 
 
 @xr.register_dataset_accessor('clean')
-class CleanDataset(object):
+class CleanDataset:
     """
     Class for cleaning up QC variables to standard cf-compliance
     """
+
     def __init__(self, xarray_obj):
         self._obj = xarray_obj
 
@@ -43,14 +45,15 @@ class CleanDataset(object):
 
         # Will need to find all historical cases and add to list
         description_list = [
-            "See global attributes for individual.+bit descriptions.",
-            ("This field contains bit packed integer values, where each "
-             "bit represents a QC test on the data. Non-zero bits indicate "
-             "the QC condition given in the description for those bits; "
-             "a value of 0.+ indicates the data has not "
-             "failed any QC tests."),
-            (r"This field contains bit packed values which should be "
-             r"interpreted as listed..+")
+            'See global attributes for individual.+bit descriptions.',
+            (
+                'This field contains bit packed integer values, where each '
+                'bit represents a QC test on the data. Non-zero bits indicate '
+                'the QC condition given in the description for those bits; '
+                'a value of 0.+ indicates the data has not '
+                'failed any QC tests.'
+            ),
+            (r'This field contains bit packed values which should be ' r'interpreted as listed..+'),
         ]
 
         # Loop over each variable and look for a match to an attribute that
@@ -80,10 +83,15 @@ class CleanDataset(object):
 
         return variables
 
-    def cleanup(self, cleanup_arm_qc=True, clean_arm_state_vars=None,
-                handle_missing_value=True, link_qc_variables=True,
-                normalize_assessment=False,
-                **kwargs):
+    def cleanup(
+        self,
+        cleanup_arm_qc=True,
+        clean_arm_state_vars=None,
+        handle_missing_value=True,
+        link_qc_variables=True,
+        normalize_assessment=False,
+        **kwargs,
+    ):
         """
         Wrapper method to automatically call all the standard methods
         for obj cleanup.
@@ -159,18 +167,25 @@ class CleanDataset(object):
            is not defined but one is needed.
 
         """
-        state_att_names = ['flag_values', 'flag_meanings',
-                           'flag_masks', 'flag_attributes']
+        state_att_names = [
+            'flag_values',
+            'flag_meanings',
+            'flag_masks',
+            'flag_attributes',
+        ]
 
         # Look for variables that have 2 of the state_att_names defined
         # as attribures and is of type float. If so assume the variable
         # was incorreclty converted to float type.
         for var in self._obj.data_vars:
             var_att_names = self._obj[var].attrs.keys()
-            if (len(set(state_att_names) & set(var_att_names)) >= 2 and
-                self._obj[var].values.dtype in
-                [np.dtype('float16'), np.dtype('float32'),
-                 np.dtype('float64')]):
+            if len(set(state_att_names) & set(var_att_names)) >= 2 and self._obj[
+                var
+            ].values.dtype in [
+                np.dtype('float16'),
+                np.dtype('float32'),
+                np.dtype('float64'),
+            ]:
 
                 # Look at units variable to see if this is the stupid way some
                 # ARM products mix data and state variables. If the units are not
@@ -218,8 +233,7 @@ class CleanDataset(object):
                 # Return data to object and add missing value indicator
                 # attribute to variable.
                 self._obj[var].values = data
-                self._obj[var].attrs['missing_value'] = \
-                    default_missing_value.astype(data.dtype)
+                self._obj[var].attrs['missing_value'] = default_missing_value.astype(data.dtype)
 
     def get_attr_info(self, variable=None, flag=False):
         """
@@ -280,20 +294,14 @@ class CleanDataset(object):
 
         try:
             if variable:
-                attr_description_pattern = (r"(^" + string +
-                                            r")_([0-9]+)_(description$)")
-                attr_assessment_pattern = (r"(^" + string +
-                                           r")_([0-9]+)_(assessment$)")
-                attr_comment_pattern = (r"(^" + string +
-                                        r")_([0-9]+)_(comment$)")
+                attr_description_pattern = r'(^' + string + r')_([0-9]+)_(description$)'
+                attr_assessment_pattern = r'(^' + string + r')_([0-9]+)_(assessment$)'
+                attr_comment_pattern = r'(^' + string + r')_([0-9]+)_(comment$)'
                 attributes = self._obj[variable].attrs
             else:
-                attr_description_pattern = (r"(^qc_" + string +
-                                            r")_([0-9]+)_(description$)")
-                attr_assessment_pattern = (r"(^qc_" + string +
-                                           r")_([0-9]+)_(assessment$)")
-                attr_comment_pattern = (r"(^qc_" + string +
-                                        r")_([0-9]+)_(comment$)")
+                attr_description_pattern = r'(^qc_' + string + r')_([0-9]+)_(description$)'
+                attr_assessment_pattern = r'(^qc_' + string + r')_([0-9]+)_(assessment$)'
+                attr_comment_pattern = r'(^qc_' + string + r')_([0-9]+)_(comment$)'
                 attributes = self._obj.attrs
         except KeyError:
             return None
@@ -382,8 +390,7 @@ class CleanDataset(object):
         # build dictionary to return values
         if len(flag_masks) > 0 or len(description_bit_num) > 0:
             return_dict = dict()
-            return_dict['flag_meanings'] = list(np.array(flag_meanings,
-                                                         dtype=str))
+            return_dict['flag_meanings'] = list(np.array(flag_meanings, dtype=str))
 
             if len(flag_masks) > 0 and max(flag_masks) > np.iinfo(np.uint32).max:
                 flag_mask_dtype = np.uint64
@@ -391,22 +398,15 @@ class CleanDataset(object):
                 flag_mask_dtype = np.uint32
 
             if flag:
-                return_dict['flag_values'] = list(np.array(description_bit_num,
-                                                           dtype=dtype))
-                return_dict['flag_masks'] = list(np.array([],
-                                                          dtype=flag_mask_dtype))
+                return_dict['flag_values'] = list(np.array(description_bit_num, dtype=dtype))
+                return_dict['flag_masks'] = list(np.array([], dtype=flag_mask_dtype))
             else:
-                return_dict['flag_values'] = list(np.array([],
-                                                           dtype=dtype))
-                return_dict['flag_masks'] = list(np.array(flag_masks,
-                                                          dtype=flag_mask_dtype))
+                return_dict['flag_values'] = list(np.array([], dtype=dtype))
+                return_dict['flag_masks'] = list(np.array(flag_masks, dtype=flag_mask_dtype))
 
-            return_dict['flag_assessments'] = list(np.array(flag_assessments,
-                                                            dtype=str))
-            return_dict['flag_tests'] = list(np.array(description_bit_num,
-                                                      dtype=dtype))
-            return_dict['flag_comments'] = list(np.array(flag_comments,
-                                                         dtype=str))
+            return_dict['flag_assessments'] = list(np.array(flag_assessments, dtype=str))
+            return_dict['flag_tests'] = list(np.array(description_bit_num, dtype=dtype))
+            return_dict['flag_comments'] = list(np.array(flag_comments, dtype=str))
             return_dict['arm_attributes'] = arm_attributes
 
         else:
@@ -415,11 +415,13 @@ class CleanDataset(object):
 
         return return_dict
 
-    def clean_arm_state_variables(self,
-                                  variables,
-                                  override_cf_flag=True,
-                                  clean_units_string=True,
-                                  integer_flag=True):
+    def clean_arm_state_variables(
+        self,
+        variables,
+        override_cf_flag=True,
+        clean_units_string=True,
+        integer_flag=True,
+    ):
         """
         Function to clean up state variables to use more CF style.
 
@@ -465,8 +467,7 @@ class CleanDataset(object):
                     pass
 
             # Clean up units attribute from unitless to udunits '1'
-            if (clean_units_string and
-                    self._obj[var].attrs['units'] == 'unitless'):
+            if clean_units_string and self._obj[var].attrs['units'] == 'unitless':
                 self._obj[var].attrs['units'] = '1'
 
     def correct_valid_minmax(self, qc_variable):
@@ -480,11 +481,13 @@ class CleanDataset(object):
             Name of quality control variable in xarray object to correct.
 
         """
-        test_dict = {'valid_min': 'fail_min',
-                     'valid_max': 'fail_max',
-                     'valid_delta': 'fail_delta'}
+        test_dict = {
+            'valid_min': 'fail_min',
+            'valid_max': 'fail_max',
+            'valid_delta': 'fail_delta',
+        }
 
-        aa = re.match(r"^qc_(.+)", qc_variable)
+        aa = re.match(r'^qc_(.+)', qc_variable)
         variable = None
         try:
             variable = aa.groups()[0]
@@ -493,8 +496,7 @@ class CleanDataset(object):
 
         made_change = False
         try:
-            flag_meanings = copy.copy(
-                self._obj[qc_variable].attrs['flag_meanings'])
+            flag_meanings = copy.copy(self._obj[qc_variable].attrs['flag_meanings'])
         except KeyError:
             return
 
@@ -504,8 +506,9 @@ class CleanDataset(object):
                     flag_meanings[ii] = re.sub(attr, test_dict[attr], test)
                     made_change = True
                     try:
-                        self._obj[qc_variable].attrs[test_dict[attr]] = \
-                            copy.copy(self._obj[variable].attrs[attr])
+                        self._obj[qc_variable].attrs[test_dict[attr]] = copy.copy(
+                            self._obj[variable].attrs[attr]
+                        )
                         del self._obj[variable].attrs[attr]
                     except KeyError:
                         pass
@@ -521,7 +524,7 @@ class CleanDataset(object):
         standard_name table in the future.
         """
         for var in self._obj.data_vars:
-            aa = re.match(r"^qc_(.+)", var)
+            aa = re.match(r'^qc_(.+)', var)
             try:
                 variable = aa.groups()[0]
                 qc_variable = var
@@ -529,24 +532,21 @@ class CleanDataset(object):
                 continue
             # Skip data quality fields.
             try:
-                if not ('Quality check results on field:' in
-                        self._obj[var].attrs['long_name']):
+                if not ('Quality check results on field:' in self._obj[var].attrs['long_name']):
                     continue
             except KeyError:
                 pass
 
             # Get existing data variable ancillary_variables attribute
             try:
-                ancillary_variables = self._obj[variable].\
-                    attrs['ancillary_variables']
+                ancillary_variables = self._obj[variable].attrs['ancillary_variables']
             except KeyError:
                 ancillary_variables = ''
 
             # If the QC variable is not in ancillary_variables add
             if qc_variable not in ancillary_variables:
                 ancillary_variables = qc_variable
-            self._obj[variable].attrs['ancillary_variables']\
-                = copy.copy(ancillary_variables)
+            self._obj[variable].attrs['ancillary_variables'] = copy.copy(ancillary_variables)
 
             # Check if QC variable has correct standard_name and iff not fix it.
             correct_standard_name = 'quality_flag'
@@ -556,11 +556,13 @@ class CleanDataset(object):
             except KeyError:
                 self._obj[qc_variable].attrs['standard_name'] = correct_standard_name
 
-    def clean_arm_qc(self,
-                     override_cf_flag=True,
-                     clean_units_string=True,
-                     correct_valid_min_max=True,
-                     remove_unset_global_tests=True):
+    def clean_arm_qc(
+        self,
+        override_cf_flag=True,
+        clean_units_string=True,
+        correct_valid_min_max=True,
+        remove_unset_global_tests=True,
+    ):
         """
         Function to clean up xarray object QC variables.
 
@@ -588,8 +590,7 @@ class CleanDataset(object):
 
             # Clean up units attribute from unitless to udunits '1'
             try:
-                if (clean_units_string and
-                        self._obj[qc_var].attrs['units'] == 'unitless'):
+                if clean_units_string and self._obj[qc_var].attrs['units'] == 'unitless':
                     self._obj[qc_var].attrs['units'] = '1'
             except KeyError:
                 pass
@@ -600,8 +601,13 @@ class CleanDataset(object):
                 qc_attributes = global_qc
 
             # Add new attributes to variable
-            for attr in ['flag_masks', 'flag_meanings',
-                         'flag_assessments', 'flag_values', 'flag_comments']:
+            for attr in [
+                'flag_masks',
+                'flag_meanings',
+                'flag_assessments',
+                'flag_values',
+                'flag_comments',
+            ]:
 
                 if qc_attributes is not None and len(qc_attributes[attr]) > 0:
                     # Only add if attribute does not exists
@@ -669,7 +675,8 @@ class CleanDataset(object):
                             break
 
                         index = self._obj.qcfilter.get_qc_test_mask(
-                            qc_var_name=qc_var_name, test_number=test_number)
+                            qc_var_name=qc_var_name, test_number=test_number
+                        )
                         if np.any(index):
                             remove_test = False
                             break
@@ -679,10 +686,16 @@ class CleanDataset(object):
 
                 if len(tests_to_remove) > 0:
                     for test_to_remove in tests_to_remove:
-                        self._obj.qcfilter.remove_test(qc_var_name=qc_var_name, test_number=test_to_remove)
+                        self._obj.qcfilter.remove_test(
+                            qc_var_name=qc_var_name, test_number=test_to_remove
+                        )
 
-    def normalize_assessment(self, variables=None, exclude_variables=None,
-                             qc_lookup={"Incorrect": "Bad", "Suspect": "Indeterminate"}):
+    def normalize_assessment(
+        self,
+        variables=None,
+        exclude_variables=None,
+        qc_lookup={'Incorrect': 'Bad', 'Suspect': 'Indeterminate'},
+    ):
 
         """
         Method to clean up assessment terms used to be consistent between
@@ -719,7 +732,8 @@ class CleanDataset(object):
         # lookup dictionary to convert the assessment terms.
         for var_name in variables:
             qc_var_name = self._obj.qcfilter.check_for_ancillary_qc(
-                var_name, add_if_missing=False, cleanup=False)
+                var_name, add_if_missing=False, cleanup=False
+            )
             if qc_var_name is not None:
                 try:
                     flag_assessments = self._obj[qc_var_name].attrs['flag_assessments']
